@@ -1,18 +1,18 @@
 #ifndef _ZZIP_MMAPPED_H_
 #define _ZZIP_MMAPPED_H_
 /*
- * NOTE: this is part of libzzipmmapped (i.e. it is not libzzip). 
+ * NOTE: this is part of libzzipmmapped (i.e. it is not libzzip).
  *
  * simplified zip disk access using a mmapping of the whole archive.
  *
- * Author: 
+ * Author:
  *      Guido Draheim <guidod@gmx.de>
  *
  * Copyright (c) 2003,2004 Guido Draheim
  *          All rights reserved,
- *          use under the restrictions of the 
+ *          use under the restrictions of the
  *          Lesser GNU General Public License
- *          or alternatively the restrictions 
+ *          or alternatively the restrictions
  *          of the Mozilla Public License 1.1
  */
 
@@ -47,6 +47,10 @@ struct zzip_disk
     long  code;        /* - free for applications (use this!) */
 };
 
+/* fnmatch search shall be case insensitive */
+#define ZZIP_DISK_FLAGS_MATCH_NOCASE 1
+#define ZZIP_DISK_FLAGS_OWNED_BUFFER 2
+
 typedef int (*zzip_strcmp_fn_t)(char*, char*);
 typedef int (*zzip_fnmatch_fn_t)(char*, char*, int);
 
@@ -61,12 +65,15 @@ zzip_disk_new(void);
 zzip_disk_extern zzip__new__ ZZIP_DISK*
 zzip_disk_mmap(int fd);
 
-zzip_disk_extern int 
+zzip_disk_extern int
 zzip_disk_munmap(ZZIP_DISK* disk);
 
 zzip_disk_extern zzip__new__ ZZIP_DISK*
 zzip_disk_open(char* filename);
 
+zzip_disk_extern zzip__new__ ZZIP_DISK *
+zzip_disk_buffer(char *buffer, size_t buflen);
+
 zzip_disk_extern int
 zzip_disk_close(ZZIP_DISK* disk);
 
@@ -87,11 +94,11 @@ zzip_disk_extern zzip_byte_t*
 zzip_disk_entry_to_data(ZZIP_DISK* disk, ZZIP_DISK_ENTRY* entry);
 
 zzip_disk_extern ZZIP_DISK_ENTRY*
-zzip_disk_findfile(ZZIP_DISK* disk, 
+zzip_disk_findfile(ZZIP_DISK* disk,
 		   char* filename, ZZIP_DISK_ENTRY* after,
 		   zzip_strcmp_fn_t compare);
 zzip_disk_extern ZZIP_DISK_ENTRY*
-zzip_disk_findmatch(ZZIP_DISK* disk, 
+zzip_disk_findmatch(ZZIP_DISK* disk,
 		    char* filespec, ZZIP_DISK_ENTRY* after,
 		    zzip_fnmatch_fn_t compare, int flags);
 
